@@ -20,7 +20,6 @@ package buffer
 
 import (
 	"io"
-	"io/ioutil"
 )
 
 // MemoryBuffer implements Buffer interface using byte slice.
@@ -43,7 +42,7 @@ func (mb MemoryBuffer) Remove() error {
 // BufferInMemory is a convenience function which creates MemoryBuffer with
 // contents of the passed io.Reader.
 func BufferInMemory(r io.Reader) (Buffer, error) {
-	blob, err := ioutil.ReadAll(r)
+	blob, err := io.ReadAll(r)
 	if err != nil {
 		return nil, err
 	}
