@@ -22,7 +22,7 @@ import (
 	"crypto/ed25519"
 	"crypto/rsa"
 	"encoding/base64"
-	"io/ioutil"
+	"os"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -44,7 +44,7 @@ func TestKeyLoad_new(t *testing.T) {
 		t.Fatal("newKey=false")
 	}
 
-	recordBlob, err := ioutil.ReadFile(filepath.Join(dir, "testkey.dns"))
+	recordBlob, err := os.ReadFile(filepath.Join(dir, "testkey.dns"))
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -82,7 +82,7 @@ func TestKeyLoad_existing_pkcs8(t *testing.T) {
 
 	dir := t.TempDir()
 
-	if err := ioutil.WriteFile(filepath.Join(dir, "testkey.key"), []byte(pkeyEd25519), 0o600); err != nil {
+	if err := os.WriteFile(filepath.Join(dir, "testkey.key"), []byte(pkeyEd25519), 0o600); err != nil {
 		t.Fatal(err)
 	}
 
@@ -134,7 +134,7 @@ func TestKeyLoad_existing_pkcs1(t *testing.T) {
 
 	dir := t.TempDir()
 
-	if err := ioutil.WriteFile(filepath.Join(dir, "testkey.key"), []byte(pkeyRSA), 0o600); err != nil {
+	if err := os.WriteFile(filepath.Join(dir, "testkey.key"), []byte(pkeyRSA), 0o600); err != nil {
 		t.Fatal(err)
 	}
 
