@@ -107,7 +107,7 @@ func (store *Storage) Init(cfg *config.Map) error {
 	var (
 		driver            string
 		dsn               []string
-		appendlimitVal    = -1
+		appendlimitVal    int64 = -1
 		compression       []string
 		authNormalize     string
 		deliveryNormalize string
@@ -168,6 +168,17 @@ func (store *Storage) Init(cfg *config.Map) error {
 		return errors.New("imapsql: driver is required")
 	}
 
+	if driver == "sqlite3" {
+		if sqliteImpl == "modernc" {
+			store.Log.Println("using transpiled SQLite (modernc.org/sqlite), this is experimental")
+			driver = "sqlite"
+		} else if sqliteImpl == "cgo" {
+			store.Log.Debugln("using cgo SQLite")
+		} else if sqliteImpl == "missing" {
+			return errors.New("imapsql: SQLite is not supported, recompile without no_sqlite3 tag set")
+		}
+	}
+
 	deliveryNormFunc, ok := authz.NormalizeFuncs[deliveryNormalize]
 	if !ok {
 		return errors.New("imapsql: unknown normalization function: " + deliveryNormalize)
@@ -221,7 +232,7 @@ func (store *Storage) Init(cfg *config.Map) error {
 	} else {
 		// int is 32-bit on some platforms, so cut off values we can't actually
 		// use.
-		if int(uint32(appendlimitVal)) != appendlimitVal {
+		if int64(uint32(appendlimitVal)) != appendlimitVal {
 			return errors.New("imapsql: appendlimit value is too big")
 		}
 		opts.MaxMsgBytes = new(uint32)
