@@ -62,8 +62,8 @@ func testTarget(t *testing.T, zones map[string]mockdns.Zone, extResolver *dns.Ex
 		policies:    extraPolicies,
 		limits:      &limits.Group{},
 		pool: pool.New(pool.Config{
-			MaxKeys:             20000,
-			MaxConnsPerKey:      10,     // basically, max. amount of idle connections in cache
+			MaxKeys:             5000,
+			MaxConnsPerKey:      5,      // basically, max. amount of idle connections in cache
 			MaxConnLifetimeSec:  150,    // 2.5 mins, half of recommended idle time from RFC 5321
 			StaleKeyLifetimeSec: 60 * 5, // should be bigger than MaxConnLifetimeSec
 		}),
@@ -154,7 +154,7 @@ func TestRemoteDelivery_NoMXFallback(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err == nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err == nil {
 		t.Fatal("Expected an error, got none")
 	}
 
@@ -275,7 +275,7 @@ func TestRemoteDelivery_Abort(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -305,7 +305,7 @@ func TestRemoteDelivery_CommitWithoutBody(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -342,7 +342,7 @@ func TestRemoteDelivery_MAILFROMErr(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	testutils.CheckSMTPErr(t, err, 550, exterrors.EnhancedCode{5, 1, 2}, "mx.example.invalid. said: Hey")
 
 	if err := delivery.Abort(context.Background()); err != nil {
@@ -368,7 +368,7 @@ func TestRemoteDelivery_NoMX(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err == nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err == nil {
 		t.Fatal("Expected an error, got none")
 	}
 
@@ -398,7 +398,7 @@ func TestRemoteDelivery_NullMX(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	testutils.CheckSMTPErr(t, err, 556, exterrors.EnhancedCode{5, 1, 10}, "Domain does not accept email (null MX)")
 
 	if err := delivery.Abort(context.Background()); err != nil {
@@ -429,7 +429,7 @@ func TestRemoteDelivery_Quarantined(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -475,10 +475,10 @@ func TestRemoteDelivery_MAILFROMErr_Repeated(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	testutils.CheckSMTPErr(t, err, 550, exterrors.EnhancedCode{5, 1, 2}, "mx.example.invalid. said: Hey")
 
-	err = delivery.AddRcpt(context.Background(), "test2@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test2@example.invalid", smtp.RcptOptions{})
 	testutils.CheckSMTPErr(t, err, 550, exterrors.EnhancedCode{5, 1, 2}, "mx.example.invalid. said: Hey")
 
 	if err := delivery.Abort(context.Background()); err != nil {
@@ -515,12 +515,12 @@ func TestRemoteDelivery_RcptErr(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	testutils.CheckSMTPErr(t, err, 550, exterrors.EnhancedCode{5, 1, 2}, "mx.example.invalid. said: Hey")
 
 	// It should be possible to, however, add another recipient and continue
 	// delivery as if nothing happened.
-	if err := delivery.AddRcpt(context.Background(), "test2@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test2@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -659,14 +659,14 @@ func TestRemoteDelivery_Split_Fail(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	if err == nil {
 		t.Fatal("Expected an error, got none")
 	}
 
 	// It should be possible to, however, add another recipient and continue
 	// delivery as if nothing happened.
-	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -712,7 +712,7 @@ func TestRemoteDelivery_BodyErr(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	err = delivery.AddRcpt(context.Background(), "test@example.invalid")
+	err = delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -766,10 +766,10 @@ func TestRemoteDelivery_Split_BodyErr(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
-	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
@@ -822,13 +822,13 @@ func TestRemoteDelivery_Split_BodyErr_NonAtomic(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if err := delivery.AddRcpt(context.Background(), "test@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
-	if err := delivery.AddRcpt(context.Background(), "test2@example.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test2@example.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
-	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid"); err != nil {
+	if err := delivery.AddRcpt(context.Background(), "test@example2.invalid", smtp.RcptOptions{}); err != nil {
 		t.Fatal(err)
 	}
 
